==> kara-uc-1.1.16.tgz: package/src/kara-uc/components/UCFavorite/All/imgComponent/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import ImgView from 'kara-module-img-view'
import Modal from 'react-modal-plugin'
import 'kara-module-img-view/lib/index.css'
import css from './index.scss'
import DataUtil from '../../../../util/dateTime'
import Forward from 'kara-module-forward'
import 'kara-module-forward/lib/index.css'
import tost,{errorTost} from "kara-module-tost";
import 'kara-module-tost/lib/index.css'

@observer
class ImgComponent extends Component{
  constructor(props) {
    super(props)
    this.state = {
      showModal: false,
      showForwardModal: false,
      activeFileId: '',
      messageId: ''
    }
  }
  showModal = (id) => {
    this.setState({activeFileId: id})
    this.setState({showModal: true})
  }
  hiddenModal = () => {
    this.setState({showModal: false})
  }
  modalForwardShow = (id) => {
    this.setState({showForwardModal: true})
    this.setState({messageId: id})
  }
  modalForwardHide = () => {
    this.setState({showForwardModal: false})
  }
  cancelFavorite = (id, type) => {
    this.props.httpAgent.post(`/webapi/message/favorite/${id}/no`).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') {
          tost({type:'success',msg:'取消收藏成功',time:4}) 
          this.props.cancelImFavorite(id, type, this.props.fromPage)
        }
        else {
          tost({type:'error',msg:'取消收藏失败',time:4}) 
        }
      }
    )
  }
  downLoadFile = (id, channelId) => {
    let abort = window.$file.download(id, channelId)
  }
  render(){
    const {lang} = this.props
    let fileAttr = this.props.fileAttr
    return (<div className={`s-b-secondary ${css.imgContainer}`}>
              <ul className={css.imgItem}>
                <li>
                  <div>
                    <p><img onClick={()=>{this.showModal(fileAttr.id)}} className='s-b-primary' src={fileAttr.thumb160} /></p>
                  </div>
                </li>
                <li className='s-hint'>
                  <span>{lang.source}&nbsp;{fileAttr.fromUserName}</span>
                  <span>{DataUtil.DateShow(fileAttr.ts)}</span>
                  <span className={css.hoverShow} onClick={()=>{this.modalForwardShow(fileAttr.messageId)}}><i className='kuc-iconfont kuc-forward'></i>&nbsp;{lang.forward}</span>
                  <span className={css.hoverShow} onClick={()=>{this.downLoadFile(fileAttr.fileId, fileAttr.channel)}}><i className='kuc-iconfont kuc-download'></i>{lang.down}</span>
                  <span className={css.hoverShow} onClick={()=>{this.cancelFavorite(fileAttr.id,fileAttr.favoriteType)}}>
                  <i className='kuc-iconfont kuc-favorite s-primary'></i>&nbsp;{lang.cancelCollect}</span>
                </li>
              </ul>
              <Modal show={this.state.showModal} parent={this.props.contentRef.current}>
                <ImgView activeFileId={this.state.activeFileId} imgList={this.props.imgViewList} imgViewClose={this.hiddenModal} ></ImgView>
              </Modal>
              <Modal show={this.state.showForwardModal} onMask={this.modalForwardHide}>
                <Forward httpAgent={this.props.httpAgent} modalHidden={this.modalForwardHide} messageId={this.state.messageId} />
              </Modal>
            </div>
            )
  }
}

export default ImgComponent

==> kara-uc-1.1.29.tgz: package/src/kara-uc/components/UCFavorite/All/imgComponent/index.js <==
import React, {Component} from 'react'
import ImgView from 'kara-module-img-view'
import Modal from 'react-modal-plugin'
import 'kara-module-img-view/lib/index.css'
import css from './index.scss'
import DataUtil from '../../../../util/dateTime'
//import Forward from 'kara-module-forward'
//import 'kara-module-forward/lib/index.css'
import tost,{errorTost} from "kara-module-tost";
import 'kara-module-tost/lib/index.css'

class ImgComponent extends Component{
  constructor(props) {
    super(props)
    this.state = {
      showModal: false,
      showForwardModal: false,
      activeFileId: '',
      messageId: '',
        height: 'auto'
    }
      this.container = React.createRef()
  }

    componentDidMount() {
        if (this.state.height === 'auto' && this.container.current) {
            this.setState({ height: this.container.current.offsetHeight})
        }
    }
  showModal = (id) => {
    this.setState({activeFileId: id})
    this.setState({showModal: true})
  }
  hiddenModal = () => {
    this.setState({showModal: false})
  }
  modalForwardShow = (id) => {
    this.setState({showForwardModal: true})
    this.setState({messageId: id})
  }
  modalForwardHide = () => {
    this.setState({showForwardModal: false})
  }
  cancelFavorite = (id, type) => {
    this.props.httpAgent.post(`/webapi/message/favorite/${id}/no`).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') {
          tost({type:'success',msg:'取消收藏成功',time:4}) 
          this.props.cancelImFavorite(id, type, this.props.fromPage)
        }
        else {
          tost({type:'error',msg:'取消收藏失败',time:4}) 
        }
      }
    )
  }
  downLoadFile = (id, channelId) => {
    let abort = window.$file.download(id, channelId)
  }
  render(){
    const {lang, karaui:{Forward}} = this.props
    let fileAttr = this.props.fileAttr
    return (<div ref={this.container} className={`s-b-secondary ${css.imgContainer}`} style={{height: fileAttr.canceled ? 0 : this.state.height}}>
              <ul className={css.imgItem}>
                <li>
                  <div>
                    <p><img onClick={()=>{this.showModal(fileAttr.id)}} className='s-b-primary' src={fileAttr.thumb160} /></p>
                  </div>
                </li>
                <li className='s-hint'>
                  <span>{lang.source}&nbsp;{fileAttr.fromUserName}</span>
                  <span>{DataUtil.DateShow(fileAttr.ts)}</span>
                  <span className={css.hoverShow} onClick={()=>{this.modalForwardShow(fileAttr.messageId)}}><i className='kuc-iconfont kuc-forward'></i>&nbsp;{lang.forward}</span>
                  <span className={css.hoverShow} onClick={()=>{this.downLoadFile(fileAttr.fileId, fileAttr.channel)}}><i className='kuc-iconfont kuc-download'></i>{lang.down}</span>
                  <span className={css.hoverShow} onClick={()=>{this.cancelFavorite(fileAttr.id,fileAttr.favoriteType)}}>
                  <i className='kuc-iconfont kuc-favorite s-primary'></i>&nbsp;{lang.cancelCollect}</span>
                </li>
              </ul>
              <Modal show={this.state.showModal} parent={this.props.contentRef.current}>
                <ImgView activeFileId={this.state.activeFileId} imgList={this.props.imgViewList} imgViewClose={this.hiddenModal} ></ImgView>
              </Modal>
              <Modal show={this.state.showForwardModal} onMask={this.modalForwardHide}>
                <Forward httpAgent={this.props.httpAgent} modalHidden={this.modalForwardHide} messageId={this.state.messageId} />
              </Modal>
            </div>
            )
  }
}

export default ImgComponent
